@@ -13,6 +13,8 @@ from urllib.parse import urlencode
 import requests
 from marshmallow import ValidationError
 from ratelimit import limits, sleep_and_retry
+from requests.adapters import HTTPAdapter
+from urllib3 import Retry
 
 # Alias these modules to prevent namespace collision with methods.
 from mokkari import __version__
@@ -309,6 +311,20 @@ class Session:
         res = self._get_results("issue", params)
         return issues.IssuesList(res)
 
+    def role_list(self, params: Dict[str, Union[str, int]] = None) -> issues.RoleList:
+        """
+        Request a list of creator roles.
+
+        :param params: Parameters to add to the request.
+        :type params: dict, optional
+
+        :return: A list of :class:`Role` objects containing their id and name.
+        :rtype: RoleList
+
+        """
+        res = self._get_results("role", params)
+        return issues.RoleList(res)
+
     def _get_results(
         self, resource: str, params: Optional[Dict[str, Union[str, int]]]
     ) -> Dict[str, Any]:
@@ -347,7 +363,7 @@ class Session:
         return data
 
     @sleep_and_retry
-    @limits(calls=20, period=ONE_MINUTE)
+    @limits(calls=25, period=ONE_MINUTE)
     def _request_data(
         self, url: str, params: Optional[Dict[str, Union[str, int]]] = None
     ) -> Any:
@@ -355,9 +371,13 @@ class Session:
             params = {}
 
         try:
-            response = requests.get(
+            session = requests.Session()
+            retry = Retry(connect=3, backoff_factor=0.5)
+            session.mount("https://", HTTPAdapter(max_retries=retry))
+            response = session.get(
                 url,
                 params=params,
+                timeout=2.5,
                 auth=(self.username, self.passwd),
                 headers=self.header,
             ).json()
